@@ -15,13 +15,13 @@
 #'
 #' @return A jar file is saved locally in the r5r package directory
 #' @family setup
-#' @examples \dontrun{ if (interactive()) {
+#' @export
+#' @examples if (interactive()) {
 #'
 #' library(r5r)
 #'
 #' download_r5(version = "6.0.1", temp_dir = TRUE)
-#' } }
-#' @export
+#' }
 
 download_r5 <- function(version = "6.0.1",
                         quiet = FALSE,
@@ -88,6 +88,7 @@ download_r5 <- function(version = "6.0.1",
       dir.create(file.path(libs, "r5r", "jar"))
     }
     message("R5 will be saved to ", destfile)
+    check_connection(url)
     utils::download.file(url = url, destfile = destfile, mode = "wb", quiet = quiet)
     return(destfile)
 
