@@ -5,6 +5,7 @@
 #' @param r5r_core a rJava object to connect with R5 routing engine
 #' @param verbose logical, passed from function above
 #'
+#' @return No return value, called for side effects.
 #' @family support functions
 
 set_verbose <- function(r5r_core, verbose) {
@@ -29,6 +30,7 @@ set_verbose <- function(r5r_core, verbose) {
 #' @param max_trip_duration numeric, Maximum trip duration in seconds. Defaults
 #'                          to 120 minutes (2 hours). Passed from routing functions.
 #'
+#' @return An `integer` representing the maximum number of minutes walking
 #' @family support functions
 
 set_max_street_time <- function(max_walk_dist, walk_speed, max_trip_duration) {
@@ -59,6 +61,7 @@ set_max_street_time <- function(max_walk_dist, walk_speed, max_trip_duration) {
 #' @param mode character string passed from routing functions.
 #' @param mode_egress character string passed from routing functions.
 #'
+#' @return A `list` with the transport modes used in the routing.
 #' @family support functions
 
 select_mode <- function(mode, mode_egress) {
@@ -122,6 +125,7 @@ select_mode <- function(mode, mode_egress) {
 #'
 #' @param datetime An object of POSIXct class.
 #'
+#' @return A `list` with the `date` and `time` of the trip departure as characters
 #' @return A list with 'date' and 'departure_time' names.
 #'
 #' @family support functions
@@ -150,7 +154,6 @@ posix_to_string <- function(datetime) {
 #' @param name Object name.
 #'
 #' @return A data.frame with columns \code{id}, \code{lon} and \code{lat}.
-#'
 #' @family support functions
 
 assert_points_input <- function(df, name) {
@@ -203,6 +206,7 @@ assert_points_input <- function(df, name) {
 #' @param r5r_core a rJava object to connect with R5 routing engine
 #' @param n_threads Any object.
 #'
+#' @return No return value, called for side effects.
 #' @family support functions
 
 set_n_threads <- function(r5r_core, n_threads) {
@@ -236,6 +240,7 @@ set_n_threads <- function(r5r_core, n_threads) {
 #' @param speed A numeric representing the speed in km/h.
 #' @param mode Either \code{"bike"} or \code{"walk"}.
 #'
+#' @return No return value, called for side effects.
 #' @family support functions
 
 set_speed <- function(r5r_core, speed, mode) {
@@ -250,7 +255,27 @@ set_speed <- function(r5r_core, speed, mode) {
 
 }
 
+#' Set max Level of Transit Stress (LTS)
+#'
+#' @param r5r_core rJava object to connect with R5 routing engine
+#' @param max_lts numeric (between 1 and 4). The maximum level of traffic stress
+#' that cyclists will tolerate. A value of 1 means cyclists will only travel
+#' through the quietest streets, while a value of 4 indicates cyclists can travel
+#' through any road.
+#'
+#' @return No return value, called for side effects.
+#' @family support functions
+#'
+set_max_lts <- function(r5r_core, max_lts) {
+  checkmate::assert_numeric(max_lts)
 
+  if (max_lts < 1 | max_lts > 4) {
+    stop(paste0(max_lts, " is not a valid value for the maximum Level of Transit Stress (LTS).\n",
+                "Please enter a value between 1 and 4."))
+  }
+
+  r5r_core$setMaxLevelTrafficStress(as.integer(max_lts))
+}
 
 #' Set max number of transfers
 #'
@@ -260,7 +285,9 @@ set_speed <- function(r5r_core, speed, mode) {
 #' @param max_rides numeric. The max number of public transport rides
 #'                  allowed in the same trip. Passed from routing function.
 #'
+#' @return No return value, called for side effects.
 #' @family support functions
+#'
 
 set_max_rides <- function(r5r_core, max_rides) {
 
@@ -290,6 +317,7 @@ set_max_rides <- function(r5r_core, max_rides) {
 #'                  the max travel time of alternatives out a bit to account for
 #'                  the fact that they don't always run on schedule.
 #'
+#' @return No return value, called for side effects.
 #' @family support functions
 
 set_suboptimal_minutes <- function(r5r_core, suboptimal_minutes) {
@@ -307,7 +335,9 @@ set_suboptimal_minutes <- function(r5r_core, suboptimal_minutes) {
 
 #' Download metadata of R5 jar files
 #' @description Support function to download metadata internally used in r5r
-#' @family general support functions
+#'
+#' @return A `data.frame` with url address of r5r Jar files
+#' @family support functions
 #'
 download_metadata <- function(){
 
@@ -324,9 +354,7 @@ download_metadata <- function(){
   # Download medata
     # test server connection
     metadata_link <- 'https://www.ipea.gov.br/geobr/r5r/metadata.csv'
-    t <- try( open.connection(con = url(metadata_link), open="rt", timeout=2),silent=TRUE)
-    if("try-error" %in% class(t)){stop('Internet connection problem. If this is not a connection problem in your network, please try r5r again in a few minutes.')}
-    suppressWarnings(try(close.connection(con),silent=TRUE))
+    check_connection(metadata_link)
 
     # download it and save it to JAR folder
     utils::download.file(url=metadata_link, destfile=metadata_file,
@@ -339,3 +367,31 @@ download_metadata <- function(){
 
   return(metadata)
 }
+
+
+
+#' Check internet connection with Ipea server
+#'
+#' @description
+#' Checks if there is internet connection to Ipea server to download geobr data.
+#'
+#' @param file_url A string with the file_url address of an geobr dataset
+#'
+#' @return No return value, called for side effects.
+#' @family support functions
+#'
+check_connection <- function(file_url = 'https://www.ipea.gov.br/geobr/metadata/metadata_gpkg.csv'){
+
+  # check internet connection
+  if (!curl::has_internet()) {
+    message("No internet connection.")
+    return(invisible(NULL))
+  }
+
+  # test server connection
+  # crul::ok(file_url)
+  if (httr::http_error(httr::GET(file_url))) {
+    message("Problem connecting to data server. Please try geobr again in a few minutes.")
+    return(invisible(NULL))
+  }
+}
